==> hadoop-client-api-3.3.2-sources.jar: org/apache/hadoop/hdfs/server/namenode/ha/HAProxyFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in org.apache.hadoop.shaded.com.liance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org.apache.hadoop.shaded.org.licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.shaded.org.apache.hadoop.hdfs.server.namenode.ha;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience;
import org.apache.hadoop.shaded.org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.shaded.org.apache.hadoop.ipc.AlignmentContext;
import org.apache.hadoop.shaded.org.apache.hadoop.security.UserGroupInformation;

import java.org.apache.hadoop.shaded.io.IOException;
import java.org.apache.hadoop.shaded.net.InetSocketAddress;
import java.util.concurrent.atomic.AtomicBoolean;

/**
 * This interface aims to decouple the proxy creation implementation that used
 * in {@link AbstractNNFailoverProxyProvider}. Client side can use
 * {@link org.apache.hadoop.shaded.org.apache.hadoop.hdfs.protocol.ClientProtocol} to initialize the
 * proxy while the server side can use NamenodeProtocols
 */
@InterfaceAudience.Private
public interface HAProxyFactory<T> {

  T createProxy(Configuration conf, InetSocketAddress nnAddr, Class<T> xface,
      UserGroupInformation ugi, boolean withRetries,
      AtomicBoolean fallbackToSimpleAuth) throws IOException;

  T createProxy(Configuration conf, InetSocketAddress nnAddr, Class<T> xface,
      UserGroupInformation ugi, boolean withRetries) throws IOException;

  /**
   * Set the alignment context to be used when creating new proxies using
   * this factory. Not all implementations will use this alignment context.
   */
  default void setAlignmentContext(AlignmentContext alignmentContext) {
    // noop
  }

}

==> hadoop-client-api-3.4.0-sources.jar: org/apache/hadoop/hdfs/server/namenode/ha/HAProxyFactory.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.shaded.org.apache.hadoop.hdfs.server.namenode.ha;

import org.apache.hadoop.shaded.org.apache.hadoop.classification.InterfaceAudience;
import org.apache.hadoop.shaded.org.apache.hadoop.conf.Configuration;
import org.apache.hadoop.shaded.org.apache.hadoop.ipc.AlignmentContext;
import org.apache.hadoop.shaded.org.apache.hadoop.security.UserGroupInformation;

import java.io.IOException;
import java.net.InetSocketAddress;
import java.util.concurrent.atomic.AtomicBoolean;

/**
 * This interface aims to decouple the proxy creation implementation that used
 * in {@link AbstractNNFailoverProxyProvider}. Client side can use
 * {@link org.apache.hadoop.shaded.org.apache.hadoop.hdfs.protocol.ClientProtocol} to initialize the
 * proxy while the server side can use NamenodeProtocols
 */
@InterfaceAudience.Private
public interface HAProxyFactory<T> {

  T createProxy(Configuration conf, InetSocketAddress nnAddr, Class<T> xface,
      UserGroupInformation ugi, boolean withRetries,
      AtomicBoolean fallbackToSimpleAuth) throws IOException;

  T createProxy(Configuration conf, InetSocketAddress nnAddr, Class<T> xface,
      UserGroupInformation ugi, boolean withRetries) throws IOException;

  /**
   * Set the alignment context to be used when creating new proxies using
   * this factory. Not all implementations will use this alignment context.
   */
  default void setAlignmentContext(AlignmentContext alignmentContext) {
    // noop
  }

}
